<?php
/*
Plugin Name: Product password protector (woocommerce)
Plugin URI: http://themeforest.net/user/alex91ckua
Description: Plugin that can be used to enable password protection for your products by creating a password for them.
Version: 1.6
Author: Alex Masliychuk (alex91ckua)
Author URI: http://alex-masliychuk.com/
Text Domain: woo-prod-protector
Domain Path: /languages
*/

if (!defined('WOO_PROD_PROTECTOR_VERSION_NUM'))
	define('WOO_PROD_PROTECTOR_VERSION_NUM', '1.6');

if ( !defined( 'WOO_PROD_PROTECTOR_PLUGIN_NAME' ) )
	define( 'WOO_PROD_PROTECTOR_PLUGIN_NAME', 'Product password protector (woocommerce)' );

if ( !defined( 'WOO_PROD_PROTECTOR_TD' ) )
	define( 'WOO_PROD_PROTECTOR_TD', 'woo-prod-protector' ); // = text domain (used for translations)

if ( !defined( 'WOO_PROD_PROTECTOR_FILE' ) )
	define( 'WOO_PROD_PROTECTOR_FILE', __FILE__ );

if ( !defined( 'WOO_PROD_PROTECTOR_PATH' ) )
	define( 'WOO_PROD_PROTECTOR_PATH', plugin_dir_path( __FILE__ ) );

if ( !defined( 'WOO_PROD_PROTECTOR_URL' ) )
	define( 'WOO_PROD_PROTECTOR_URL', plugin_dir_url( __FILE__ ) );


class WooProductProtector_Init
{

	function __construct() {

		add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );

		if ( is_admin() ) {
			add_action( 'plugins_loaded', array( $this, 'admin_init' ), 14 );
		}
		else {
			add_action( 'plugins_loaded', array( $this, 'frontend_init' ), 14 );
		}

        register_activation_hook ( WOO_PROD_PROTECTOR_FILE, array( $this, 'install' ) );
	}

    /**
     * Set default global password on activation
     */
    function install() {
        update_option('product_protector', '1234');
    }

    /**
	 * Load plugin textdomain.
	 * @since 1.5
	 */
	function load_textdomain() {
		load_plugin_textdomain( WOO_PROD_PROTECTOR_TD, false, dirname( plugin_basename( WOO_PROD_PROTECTOR_FILE ) ) . '/languages/' );
	}

	function admin_init() {
		if (current_user_can('manage_options')) {
			require_once( WOO_PROD_PROTECTOR_PATH . 'admin/class-admin.php' );
		}
	}

	function frontend_init() {
		require_once( WOO_PROD_PROTECTOR_PATH . 'frontend/class-frontend.php' );
	}

}

new WooProductProtector_Init();